import { Space, Table, Button, Image, Divider, Badge, Modal, notification, message } from 'antd';
import type { TableColumnsType } from 'antd';
import { t } from '@/utils/i18n';
import React, { useState } from 'react';
import mData from '../../../../../mock/productListPage.json'
import { PlusOutlined, ExclamationCircleFilled } from '@ant-design/icons';
import type { Product, ProductBase, ProductImage, ProductSku } from '@/models'

const { confirm } = Modal;
type NotificationType = 'success' | 'info' | 'warning' | 'error';
//成品
const FinishedProductPage: React.FC = () => {

  const [notificationApi, notificationContextHolder] = notification.useNotification();
  const [messageApi, messageContextHolder] = message.useMessage();

  const openNotificationWithIcon = (type: NotificationType) => {
    notificationApi[type]({
      message: '删除成功',
      description:
        '商品信息已删除',
    });
  };

  const showDeleteConfirm = () => {
    confirm({
      title: '确认要将该商品删除吗？',
      icon: <ExclamationCircleFilled />,
      content: '请注意删除以后不可恢复！',
      okText: '删除',
      okType: 'danger',
      cancelText: '取消',
      onOk() {
        return new Promise((resolve, reject) => {
          setTimeout(() => {
            messageApi.open({
              type: 'success',
              content: '删除成功',
            });
            resolve(null)
          }, 1000);
          // openNotificationWithIcon('success')

        }).catch(() => messageApi.open({
          type: 'error',
          content: '操作失败',
        }));
      },
      onCancel() {
      },
    });
  };

  const columns: TableColumnsType<Product> = [
    {
      title: '商品主图',
      dataIndex: 'productImgs',
      key: 'productImgs',
      render: (value: ProductImage[]) => (
        value.length > 0 && <Image className='bg-[gold]' src={value[0].imgUrl} />
      ),
      align: 'center',
      width: 100,
    },
    {
      title: 'SPU编码',
      dataIndex: 'spuCode',
      key: 'spuCode',
      width: 100,
    },
    {
      title: '数据源',
      dataIndex: 'sourceType',
      key: 'sourceType',
      width: 100,
      render: (value: number) => (value == 4 ? 'diy导入' : '未知')
    },
    {
      title: '商品标题',
      key: 'base',
      dataIndex: 'base',
      render: (value: ProductBase) => (
        <>
          <div>{value.productName}</div>
          <div>{value.productNameEn}</div>
        </>
      )
    },
    {
      title: '类目',
      key: 'category',
      dataIndex: ['category', 'categoryName'],
      width: 100,
    },
    {
      title: '商品状态',
      key: 'productStatus',
      dataIndex: 'productStatus',
      width: 100,
      render: (value: number) => {
        return (value === 1 ? <Badge status="error" text="未审核" /> : <Badge status="success" text="已审核" />)
      }
    },
    {
      title: '总销售额',
      key: 'specimenNumber',
      dataIndex: 'specimenNumber',
      width: 100,
      render: (value: number) => ('-')
    },
    {
      title: '创建人',
      dataIndex: 'creatorName',
      key: 'creatorName',
      width: 150,
    },
    {
      title: '创建时间',
      key: 'createTime',
      dataIndex: 'createTime',
      width: 200,
    },
    {
      title: t("QkOmYwne" /* 操作 */),
      key: 'action',
      render: (_, record) => (
        <Space size="small" split={(
          <Divider type='vertical' />
        )}>
          <a
            onClick={() => {

            }}>
            编辑
          </a>
          <a
            onClick={() => {
              showDeleteConfirm()
            }}>
            删除
          </a>
          <a
            onClick={() => {

            }}>
            认领商品
          </a>
        </Space>
      ),
      width: 250,
    },
  ];

  const expandedColumnsRender = (item: Product) => {
    const expandedColumns: TableColumnsType<ProductSku> = [
      { title: '序号', key: 'index', align: 'center', render: (data, _, index) => (<>{index}</>) },
      {
        title: '缩略图', dataIndex: 'skuImgUrl', key: 'productImgs', width: 80, render: (value: string) => (
          <Image className='bg-[gold] align-middle flex items-center justify-center w-[40px] h-[40px]' src={value} />
        )
      },
      { title: 'SKU编码', dataIndex: 'skuCode', key: 'spuCode' },
      { title: '建议零售价', dataIndex: 'costPrice', key: 'costPrice' },
      { title: '重量', dataIndex: 'weight', key: 'weight' },
      { title: '销售额', dataIndex: 'packCost', key: 'packCost' },
      { title: '长', dataIndex: 'length', key: 'length' },
      { title: '宽', dataIndex: 'width', key: 'width' },
      { title: '高', dataIndex: 'height', key: 'height' }
    ];
    const data: Array<ProductSku> = item.productSkus;
    return <Table columns={expandedColumns} dataSource={data} pagination={false} size='small' />;
  }

  const data: Array<Product> = mData as Array<Product>;

  return (
    <>
      {notificationContextHolder}
      {messageContextHolder}
      <div className='mt-[4px] dark:bg-[rgb(33,41,70)] bg-white roundle-lg px[12px]'>
        <div className="py-[8px]">
          <Button className="ml-5" type='primary' size='large' icon={<PlusOutlined />}> 批量操作 </Button>
        </div>
        <Table rowKey="id"
          scroll={{ x: true }}
          columns={columns}
          expandable={{ expandedRowRender: expandedColumnsRender, defaultExpandedRowKeys: ['0'] }}
          dataSource={data}
          className='bg-transparent'
          pagination={{ position: ['bottomRight'] }} />
      </div>
    </>

  );
};

export default FinishedProductPage;
