import { Space, Tag, Table, Modal, message, Col, Input, InputNumber, Button, Avatar, Divider } from 'antd';
import type { ColumnsType } from 'antd/es/table';
import { t } from '@/utils/i18n';
import { IconBuguang } from '@/assets/icons/buguang';
import React, { useState } from 'react';
import type { TableRowSelection } from 'antd/es/table/interface';
import mData from '../../../../../mock/findMaterialPage.json'
import { PlusOutlined, ExclamationCircleFilled } from '@ant-design/icons';

const { confirm } = Modal;

interface Classify {
  id: number;
  classifyName: string;
}

interface DataType {
  id: number;
  createTime: string;
  classifyId: number;
  materialImgId: number;
  materialName: string;
  materialRemark: string;
  materialWidth: number;
  materialHeight: number;
  materialSize: number;
  createId: number;
  materialImgUrl: string;
  dictDetails: string[];
  classify: Classify;
}

const TablePage: React.FC = () => {
  const [messageApi, messageContextHolder] = message.useMessage();

  const showDeleteConfirm = (item: DataType) => {
    confirm({
      title: `确认删除标题为: ${item.materialName} 的素材吗?`,
      icon: <ExclamationCircleFilled />,
      content: '请注意删除以后不可恢复！',
      okText: '删除',
      okType: 'danger',
      cancelText: '取消',
      onOk() {
        return new Promise((resolve, reject) => {
          setTimeout(() => {
            messageApi.open({
              type: 'success',
              content: '删除成功',
            });
            resolve(null)
          }, 1000);

        }).catch(() => messageApi.open({
          type: 'error',
          content: '操作失败',
        }));
      },
      onCancel() {
      },
    });
  };

  const columns: ColumnsType<DataType> = [
    {
      title: '图片',
      dataIndex: 'materialImgUrl',
      key: 'materialImgUrl',
      render: (value: string) => (
        <div className='flex justify-center'>
          {value ? (
            <img src={value} className='w-[40px] h-[40px] flex items-center rounded-[50%]' />
          ) : (
            <Avatar className='bg-[gold] align-middle flex items-center justify-center w-[40px] h-[40px]' icon={<IconBuguang />} />
          )}
        </div>
      ),
      align: 'center',
      width: 100,
    },
    {
      title: '标题',
      dataIndex: 'materialName',
      key: 'materialName',
      width: 150,
    },
    {
      title: '分类',
      dataIndex: ['classify', 'classifyName'],
      key: 'classify',
      width: 80,
      filters: [
        {
          text: '全部素材',
          value: '1',
        },
        {
          text: '卡通',
          value: '2',
          children: [
            {
              text: '海贼王',
              value: '20',
            },
            {
              text: '火影忍者',
              value: '21',
            },
            {
              text: '死神',
              value: '22',
            },
          ],
        },
        {
          text: '风景',
          value: '3',
        },
        {
          text: '插图',
          value: '4',
        },
        {
          text: '模型',
          value: '5',
        },
        {
          text: '图标',
          value: '6',
        },
        {
          text: '其他',
          value: '52',
        },
      ],
      filterMode: 'tree',
      filterSearch: false,
    },
    {
      title:'描述',
      key: 'materialRemark',
      dataIndex: 'materialRemark'
    },
    {
      title: '分辨率',
      key: 'materialInfo',
      render:(_, record) => (
        <>
        {record.materialWidth}px * {record.materialHeight}px
        </>
      ),
      width: 150,
    },
    {
      title: '图片大小',
      dataIndex: 'materialSize',
      key: 'materialRemark',
      render:(value: number) => (
        <>
        {value}kb
        </>
      ),
      width: 100,
    },
    {
      title:'上传时间',
      key: 'createTime',
      dataIndex: 'createTime',
      width: 200,
    },
    {
      title: t("QkOmYwne" /* 操作 */),
      key: 'action',
      render: (_, record) => (
        <Space size="middle" split={(
          <Divider type='vertical' />
        )}>
          <a
            onClick={() => {
              // setCreateVisible(true);
              // setCurRowData(record);
            }}>
            编辑
          </a>
          <a
            onClick={() => {
              showDeleteConfirm(record)
            }}>
              删除
            </a>
        </Space>
      ),
      width: 150,
    },
  ];

  const data: Array<DataType> = mData as Array<DataType>;

  const [selectedRowKeys, setSelectedRowKeys] = useState<React.Key[]>([]);

  const onSelectChange = (newSelectedRowKeys: React.Key[]) => {
    console.log('selectedRowKeys changed: ', newSelectedRowKeys);
    setSelectedRowKeys(newSelectedRowKeys);
  };

  const rowSelection: TableRowSelection<DataType> = {
    selectedRowKeys,
    onChange: onSelectChange,
    selections: [
      Table.SELECTION_ALL,
      Table.SELECTION_INVERT,
      Table.SELECTION_NONE,
      {
        key: 'odd',
        text: 'Select Odd Row',
        onSelect: (changeableRowKeys) => {
          let newSelectedRowKeys = [];
          newSelectedRowKeys = changeableRowKeys.filter((_, index) => {
            if (index % 2 !== 0) {
              return false;
            }
            return true;
          });
          setSelectedRowKeys(newSelectedRowKeys);
        },
      },
      {
        key: 'even',
        text: 'Select Even Row',
        onSelect: (changeableRowKeys) => {
          let newSelectedRowKeys = [];
          newSelectedRowKeys = changeableRowKeys.filter((_, index) => {
            if (index % 2 !== 0) {
              return true;
            }
            return false;
          });
          setSelectedRowKeys(newSelectedRowKeys);
        },
      },
    ],
  };


  return (
    <>
      {messageContextHolder}
      <div className='mt-[4px] dark:bg-[rgb(33,41,70)] bg-white roundle-lg px[12px]'>
      <div className="py-[8px]">
        <Button className="ml-5" type='primary' size='large' icon={<PlusOutlined/>}> 新增素材 </Button>
      </div>
      <Table rowKey="id" rowSelection={rowSelection} scroll={{ x: true }} columns={columns} dataSource={data} className='bg-transparent' 
          pagination={{ position: ['bottomRight'] }}
        />
    </div>
    </>

  );
};

export default TablePage;
